Skip to main content Crate icentral_3p Copy item path Source pub use tracing ;pub use rand ;pub use serde_json ;pub use serde ;pub use text_io ;pub use lib_dachshund ;pub use paste ;atomic Atomic types fmt Utilities for formatting and printing Strings. io Traits, helpers, and type definitions for core I/O functionality. arc arcmut arcmut_with debug Constructs an event at the debug level. default construct me one default, please! delegate error Constructs an event at the error level. error_tree info Constructs an event at the info level. ix pbx rc rcmut read All text input is handled through this macro trace Constructs an event at the trace level. try_read warn Constructs an event at the warn level. x zeroed we typically use this when interactinge with
wrappers around C apis which do not have/need
default constructors Arc A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically
Reference Counted’. BoxMakeWriter A writer that erases the specific io::Write and MakeWriter types being used. BufReader The BufReader<R> struct adds buffering to any reader. BufWriter Wraps a writer and buffers its output. BufferedRng A buffered wrapper for any Rng implementation.
It will keep unused bytes from the last call to Rng::rand , and use them
for subsequent randomness if needed, rather than throwing them away. Duration A Duration type to represent a span of time, typically used for system
timeouts. EnvFilter A Layer which filters spans and events based on a set of filter
directives. File An object providing access to an open file on the filesystem. FloatOrd A wrapper for floats, that implements total equality and ordering
and hashing. FmtSubscriber A Subscriber that logs formatted representations of tracing events. HashMap A hash map implemented with quadratic probing and SIMD lookup. HashSet A hash set implemented as a HashMap where the value is (). Instant A measurement of a monotonically nondecreasing clock.
Opaque and useful only with Duration . Level Describes the level of verbosity of a span or event. Mutex A mutual exclusion primitive useful for protecting shared data MutexGuard An RAII implementation of a “scoped lock” of a mutex. When this structure is
dropped (falls out of scope), the lock will be unlocked. ParseIntError An error which can be returned when parsing an integer. Pin A pointer which pins its pointee in place. PoisonError A type of error which can be returned whenever a lock is acquired. Queue A first in, first out queue built around Vec. Range A (half-open) range bounded inclusively below and exclusively above
(start..end). Rc A single-threaded reference-counting pointer. ‘Rc’ stands for ‘Reference
Counted’. RefCell A mutable memory location with dynamically checked borrow rules Stack A lock-free stack. LIFO/FILO semanthics are fully respected. SystemTime A measurement of the system clock, useful for talking to
external entities like the file system or other processes. WyRand An instance of the WyRand random number generator.
Seeded from the system entropy generator when available.
This generator is NOT cryptographically secure. Cow A clone-on-write smart pointer. Json Represents any valid JSON value. BufRead A BufRead is a type of Reader which has an internal buffer, allowing it
to perform extra ways of reading. DeError The Error trait allows Deserialize implementations to create descriptive
error messages belonging to the Deserializer against which they are
currently running. Debug ? formatting.Deserialize A data structure that can be deserialized from any data format supported
by Serde. DeserializeOwned A data structure that can be deserialized without borrowing any data from
the deserializer. Deserializer A data format that can deserialize any data structure supported by
Serde. Index Used for indexing operations (container[index]) in immutable contexts. IndexMut Used for indexing operations (container[index]) in mutable contexts. Read The Read trait allows for reading bytes from a source. Rng A trait that represents a random number generator. Roots Provides methods to compute an integer’s square root, cube root,
and arbitrary nth root. Serialize A data structure that can be serialized into any data format supported
by Serde. SerializeStruct Returned from Serializer::serialize_struct. SerializeStructVariant Returned from Serializer::serialize_struct_variant. Serializer A data format that can serialize any data structure supported by Serde. SliceRandom Extension trait on slices, providing random mutation and sampling methods. Write A trait for objects which are byte-oriented sinks. min Compares and returns the minimum of two values. pin_arc Converts an Arc to a Pin<Arc> pin_box Converts a Box to a Pin<Box> sort Sort a slice of floats. AtomicBool A boolean type which can be safely shared between threads. AtomicI32 An integer type which can be safely shared between threads. AtomicU32 An integer type which can be safely shared between threads. AtomicUsize An integer type which can be safely shared between threads. LockResult A type alias for the result of a lock method which can be poisoned. Pbx Debug Derive macro generating an impl of the trait Debug.